Index: code/branches/questsystem2/src/orxonox/objects/quest/Quest.cc
===================================================================
--- code/branches/questsystem2/src/orxonox/objects/quest/Quest.cc	(revision 2159)
+++ code/branches/questsystem2/src/orxonox/objects/quest/Quest.cc	(revision 2191)
@@ -84,9 +84,9 @@
     /**
     @brief
-        Sets the parent quest of the quest.
+        Sets the parentquest of the Quest.
     @param quest
-        A pointer to the quest to be set as parent quest.
-    @return
-        Returns true if the parentQuest could be set.
+        A pointer to the Quest to be set as parentquest.
+    @return
+        Returns true if the parentquest could be set.
     */
     bool Quest::setParentQuest(Quest* quest)
@@ -106,9 +106,9 @@
     /**
     @brief
-        Adds a sub quest to the quest.
+        Adds a subquest to the Quest.
     @param quest
-        A pointer to the quest to be set as sub quest.
-    @return
-        Returns true if the subQuest vould be set.
+        A pointer to the Quest to be set as subquest.
+    @return
+        Returns true if the subquest could be set.
     */
     bool Quest::addSubQuest(Quest* quest)
@@ -120,6 +120,6 @@
         }
 
-        quest->setParentQuest(this); //!< Sets the current quest (this) as parent quest for the added subquest.
-        this->subQuests_.push_back(quest); //!< Adds the quest to the end of the list of subquests.
+        quest->setParentQuest(this); //!< Sets the currentQuest (this) as parentquest for the added subquest.
+        this->subQuests_.push_back(quest); //!< Adds the Quest to the end of the list of subquests.
 
         COUT(3) << "Sub Quest {" << quest->getId() << "} was added to Quest {" << this->getId() << "}." << std::endl;
@@ -130,7 +130,7 @@
     /**
     @brief
-        Adds a Hint to the list of hints
+        Adds a QuestHint to the list of QuestHints
     @param hint
-        The hint that should be added to the list of hints.
+        The QuestHint that should be added to the list of QuestHints.
     @return
         Returns true if the hint was successfully added.
@@ -144,6 +144,6 @@
         }
 
-        hint->setQuest(this); //!< Sets the current quest (this) as quest for the added hint.
-        this->hints_.push_back(hint); //!< Adds the hint to the end of the list of hints.
+        hint->setQuest(this); //!< Sets the current Quest (this) as Quest for the added QuestHint.
+        this->hints_.push_back(hint); //!< Adds the QuestHint to the end of the list of QuestHints.
 
         COUT(3) << "QuestHint {" << hint->getId() << "} was added to Quest {" << this->getId() << "}." << std::endl;
@@ -153,5 +153,5 @@
     /**
     @brief
-        Adds an effect to the list of failEffects.
+        Adds an QuestEffect to the list of fail QuestEffects.
     @param effect
         The QuestEffect to be added.
@@ -167,5 +167,5 @@
         }
 
-        this->failEffects_.push_back(effect); //!< Adds the effect to the end of the list of failEffects.
+        this->failEffects_.push_back(effect); //!< Adds the QuestEffect to the end of the list of fail QuestEffects.
 
         COUT(3) << "A FailEffect was added to Quest {" << this->getId() << "}." << std::endl;
@@ -175,5 +175,5 @@
     /**
     @brief
-        Adds an effect to the list of completeEffects.
+        Adds an QuestEffect to the list of complete QuestEffects.
     @param effect
         The QuestEffect to be added.
@@ -189,5 +189,5 @@
         }
 
-        this->completeEffects_.push_back(effect); //!< Adds the effect to the end of the list of completeEffects.
+        this->completeEffects_.push_back(effect); //!< Adds the QuestEffect to the end of the list of complete QuestEffects.
 
         COUT(3) << "A CompleteEffect was added to Quest {" << this->getId() << "}." << std::endl;
@@ -197,7 +197,7 @@
     /**
     @brief
-        Returns the parent quest of the quest.
-    @return
-        Returns the parent quest of the quest.
+        Returns the parentquest of the Quest.
+    @return
+        Returns a pointer to the parentquest of the Quest.
     */
     const Quest* Quest::getParentQuest(void)
@@ -208,9 +208,9 @@
     /**
     @brief
-        Returns the sub quest of the given index.
+        Returns the subquest at the given index.
     @param
         The index.
     @return
-        Returns the subquest of the given index. NULL if there is no element on the given index.
+        Returns a pointer to the subquest at the given index. NULL if there is no element at the given index.
     */
     const Quest* Quest::getSubQuest(unsigned int index) const
@@ -233,9 +233,9 @@
     /**
     @brief
-        Returns the hint of the given index.
+        Returns the QuestHint at the given index.
     @param
         The index.
     @return
-        Returns the hint of the given index. NULL if there is no element on the given index.
+        Returns a pointer to the QuestHint at the given index. NULL if there is no element at the given index.
     */
     const QuestHint* Quest::getHint(unsigned int index) const
@@ -243,5 +243,5 @@
         int i = index;
         
         //! Iterate through all hints.
         for (std::list<QuestHint*>::const_iterator hint = this->hints_.begin(); hint != this->hints_.end(); ++hint)
         {
@@ -257,9 +257,9 @@
     /**
     @brief
-        Returns the failEffect of the given index.
+        Returns the fail QuestEffect at the given index.
     @param
         The index.
     @return
-        Returns the failEffect of the given index. NULL if there is no element on the given index.
+        Returns a pointer to the fail QuestEffect at the given index. NULL if there is no element at the given index.
     */
     const QuestEffect* Quest::getFailEffect(unsigned int index) const
@@ -267,5 +267,5 @@
         int i = index;
         
         //! Iterate through all failEffects.
         for (std::list<QuestEffect*>::const_iterator effect = this->failEffects_.begin(); effect != this->failEffects_.end(); ++effect)
         {
@@ -281,9 +281,9 @@
     /**
     @brief
-        Returns the completeEffect of the given index.
+        Returns the complete QuestEffect at the given index.
     @param
         The index.
     @return
-        Returns the completeEffect of the given index. NULL if there is no element on the given index.
+        Returns a pointer to the complete QuestEffect at the given index. NULL if there is no element at the given index.
     */
     const QuestEffect* Quest::getCompleteEffect(unsigned int index) const
@@ -291,5 +291,5 @@
         int i = index;
         
         //! Iterate through all completeEffects.
         for (std::list<QuestEffect*>::const_iterator effect = this->completeEffects_.begin(); effect != this->completeEffects_.end(); ++effect)
         {
@@ -366,9 +366,9 @@
     /**
     @brief
-        Starts the quest for an input player.
-    @param player
-        The player.
-    @return
-        Returns true if the quest could be started, false if not.
+        Starts the Quest for an input player.
+    @param player
+        The player.
+    @return
+        Returns true if the Quest could be started, false if not.
     */
     bool Quest::start(ControllableEntity* player)
@@ -243,5 +243,5 @@
         int i = index;
         
-        //! Iterate through all hints.
+        //! Iterate through all QuestHints.
         for (std::list<QuestHint*>::const_iterator hint = this->hints_.begin(); hint != this->hints_.end(); ++hint)
         {
@@ -267,5 +267,5 @@
         int i = index;
         
-        //! Iterate through all failEffects.
+        //! Iterate through all fail QuestEffects.
         for (std::list<QuestEffect*>::const_iterator effect = this->failEffects_.begin(); effect != this->failEffects_.end(); ++effect)
         {
@@ -291,5 +291,5 @@
         int i = index;
         
-        //! Iterate through all completeEffects.
+        //! Iterate through all complete QuestEffects.
         for (std::list<QuestEffect*>::const_iterator effect = this->completeEffects_.begin(); effect != this->completeEffects_.end(); ++effect)
         {
